@@ -7,8 +7,7 @@
 #    http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# distributed under the License is distributed on an "AS IS" BASIS, # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
@@ -41,7 +40,6 @@ class FetchWorker(Peasant):
                 self.repository.fetch(self.upstream, self.branch)
                 fetch_successful.set()
                 log.debug("Fetch done")
-            except Exception as e:
+            except:
                 fetch_successful.clear()
-                log.warn("Fetch failed")
-                log.exception(e)
+                log.exception("Fetch failed")
